# -*- coding:utf-8 -*-

"""
This file is part of OpenSesame.

OpenSesame is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

OpenSesame is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with OpenSesame.  If not, see <http://www.gnu.org/licenses/>.
"""
icon_map = u'../default/icon_map.csv'
icon_theme = u'MokaSesame'
icon_theme_path = u'default'
qss = u'stylesheet.qss'
qdatamatrix = {
    'HEADER_BACKGROUND': '#49483e',
    'HEADER_FOREGROUND': '#f8f8f2',
    'CELL_BACKGROUND': '#272822',
    'CELL_NUMERIC_FOREGROUND': '#a6e22e',
    'CELL_TEXT_FOREGROUND': '#f8f8f2'
}
